<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage  Blogpost
 * @since  Blogpost 1.0.0
 */

get_header(); 
$options                = blogpost_get_theme_options();

if(!blogpost_is_latest_posts()) : ?>  

	<div id="inner-content-wrapper" class="wrapper page-section">
		<div id="primary" class="content-area">
			<main id="main" class="site-main" role="main">
				<div id="blogpost_latest_posts" class="grid-layout <?php echo esc_attr( $options['blog_column'] ); ?> clear">
					<?php
					if ( have_posts() ) : ?>

						<?php
						/* Start the Loop */
						while ( have_posts() ) : the_post();

							/*
							* Include the Post-Format-specific template for the content.
							* If you want to override this in a child theme, then include a file
							* called content-___.php (where ___ is the Post Format name) and that will be used instead.
							*/
							get_template_part( 'template-parts/content', get_post_format() );

						endwhile;

					else :

						get_template_part( 'template-parts/content', 'none' );

					endif; ?>
				</div>
				<?php  
				/**
				* Hook - blogpost_action_pagination.
				*
				* @hooked blogpost_pagination 
				*/
				do_action( 'blogpost_action_pagination' ); 

				/**
				* Hook - blogpost_infinite_loader_spinner_action.
				*
				* @hooked blogpost_infinite_loader_spinner 
				*/
				do_action( 'blogpost_infinite_loader_spinner_action' );
				?>
			</main><!-- #main -->
		</div><!-- #primary -->

		<?php  
		if ( blogpost_is_sidebar_enable() ) {
			get_sidebar();
		}
		?>
	</div><!-- .wrapper -->

<?php endif;
get_footer();
